==> libjo_01_25.tar.gz: smarty_dir/templates_c/%%E7^E7B^E7BDF484%%entry.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-25 16:15:21
         compiled from entry.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">
	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div id="content">
	<div id="pan">

	</div> 
	<div id="center_main">
	<div id="entry">
					
	<h2> 会員登録	</h2>		
	
	<p> 学籍番号とパスワードを入力してください </p>
				
	<form action="entry_confirm.php" method="POST">
					<div id="entry_form">

					<ul>
					<li ><span>学籍番号</span>：</li>	
					<li><input type="text" name="id" class="text" value="<?php echo $_POST['id']; ?>
"> </li>
					</ul>

					<ul>
					<li ><span>お名前</span>：</li>	
					<li><input type="text" name="name" class="text" value="<?php echo $_POST['id']; ?>
"> </li>
					</ul>
					

					
					<br />	
					<ul>
					<li ><span>パスワード</span>：</li>
					<li>
					<input type="password" name="pass1" class="text" value="">
					</li>

					</ul>
					<br />	
					
					<ul>
					<li ><span>パスワード(確認)</span>：</li>
					<li><input type="password" name="pass2" class="text" value=""></li>
					</ul>
					<br />
					<ul class="submit">
					<li> <input type="submit" value="ユーザ登録"> </li>
					</ul>
					</div> 					</form>


				</div> 
	
	</div> 
</div> <?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

</body>
</html>

==> libjo_01_26.tar.gz: smarty_dir/templates_c/%%E7^E7B^E7BDF484%%entry.tpl.php <==
<?php /* Smarty version 2.6.20, created on 2009-01-26 17:29:46
         compiled from entry.tpl */ ?>
<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "DTD.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<body>
<!--全体-->
<div id="wrapper">
	<?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "header.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>
<div id="content">
	<div id="pan">

	</div> 
	<div id="center_main">
	<div id="entry">
					
	<h2> 会員登録	</h2>		
	
	<p> 学籍番号とパスワードを入力してください </p>
				
	<form  method="POST">
					<div id="entry_form">

					<ul>
					<li ><span>学籍番号</span>：</li>	
					<li><input type="text" name="id" class="text" value="<?php echo $_POST['id']; ?>
"> </li>
					</ul>

					<ul>
					<li ><span>お名前</span>：</li>	
					<li><input type="text" name="name" class="text" value="<?php echo $_POST['id']; ?>
"> </li>
					</ul>
					

					
					<br />	
					<ul>
					<li ><span>パスワード</span>：</li>
					<li>
					<input type="password" name="pass1" class="text" value="">
					</li>

					</ul>
					<br />	
					
					<ul>
					<li ><span>パスワード(確認)</span>：</li>
					<li><input type="password" name="pass2" class="text" value=""></li>
					</ul>
					<br />
					<ul class="submit">
					<li> <input type="submit" value="ユーザ登録"> </li>
					</ul>
					</div> 					</form>


				</div> 
	
	</div> 
</div> <?php $_smarty_tpl_vars = $this->_tpl_vars;
$this->_smarty_include(array('smarty_include_tpl_file' => "footer.tpl", 'smarty_include_vars' => array()));
$this->_tpl_vars = $_smarty_tpl_vars;
unset($_smarty_tpl_vars);
 ?>

</body>
</html>
